#include "chartform.h"
#include "ui_chartform.h"

ChartForm::ChartForm(QWidget *parent) :
    QWidget(parent),
    ui(new Ui::ChartForm)
{
    ui->setupUi(this);
    SetBackGround();
}

ChartForm::~ChartForm()
{
    delete ui;
}

void ChartForm::SetBackGround()
{
    ui->qcustomPlot->xAxis->setBasePen(QPen(Qt::white, 1));
    ui->qcustomPlot->yAxis->setBasePen(QPen(Qt::white, 1));
    ui->qcustomPlot->xAxis->setTickPen(QPen(Qt::white, 1));
    ui->qcustomPlot->yAxis->setTickPen(QPen(Qt::white, 1));
    ui->qcustomPlot->xAxis->setSubTickPen(QPen(Qt::white, 1));
    ui->qcustomPlot->yAxis->setSubTickPen(QPen(Qt::white, 1));
    ui->qcustomPlot->xAxis->setTickLabelColor(Qt::white);
    ui->qcustomPlot->yAxis->setTickLabelColor(Qt::white);
    ui->qcustomPlot->xAxis->grid()->setPen(QPen(QColor(140, 140, 140), 1, Qt::DotLine));
    ui->qcustomPlot->yAxis->grid()->setPen(QPen(QColor(140, 140, 140), 1, Qt::DotLine));
    ui->qcustomPlot->xAxis->grid()->setSubGridPen(QPen(QColor(80, 80, 80), 1, Qt::DotLine));
    ui->qcustomPlot->yAxis->grid()->setSubGridPen(QPen(QColor(80, 80, 80), 1, Qt::DotLine));
    ui->qcustomPlot->xAxis->grid()->setSubGridVisible(true);
    ui->qcustomPlot->yAxis->grid()->setSubGridVisible(true);
    ui->qcustomPlot->xAxis->grid()->setZeroLinePen(Qt::NoPen);
    ui->qcustomPlot->yAxis->grid()->setZeroLinePen(Qt::NoPen);
    ui->qcustomPlot->xAxis->setUpperEnding(QCPLineEnding::esSpikeArrow);
    ui->qcustomPlot->yAxis->setUpperEnding(QCPLineEnding::esSpikeArrow);
    QLinearGradient plotGradient;
    plotGradient.setStart(0, 0);
    plotGradient.setFinalStop(0, 350);
    plotGradient.setColorAt(0, QColor(80, 80, 80));
    plotGradient.setColorAt(1, QColor(50, 50, 50));
    ui->qcustomPlot->setBackground(plotGradient);
    QLinearGradient axisRectGradient;
    axisRectGradient.setStart(0, 0);
    axisRectGradient.setFinalStop(0, 350);
    axisRectGradient.setColorAt(0, QColor(80, 80, 80));
    axisRectGradient.setColorAt(1, QColor(30, 30, 30));
    ui->qcustomPlot->axisRect()->setBackground(axisRectGradient);

    ui->qcustomPlot->setInteractions(QCP::iRangeDrag | QCP::iRangeZoom);
    ui->qcustomPlot->setOpenGl(true);
    qDebug()<< "“opengle=”" << ui->qcustomPlot->openGl();
}

void ChartForm::PlotLine(QVector<QCPCurveData> dataSpiral, QColor _color, int _width)
{
    QCPCurve * odo_line;

    odo_line = new QCPCurve(ui->qcustomPlot->xAxis, ui->qcustomPlot->yAxis);

    // pass the data to the curves; we know t (i in loop above) is ascending, so set alreadySorted=true (saves an extra internal sort):
    odo_line->data()->set(dataSpiral, true);

    QPen pen;
    pen.setWidth(_width);
    pen.setColor(_color);

    odo_line->setPen(pen);


}

void ChartForm::PlotPoints(QVector<QCPCurveData> dataSpiral, QColor _color)
{
    // 绘制散点
    QCPGraph * curGraph = ui->qcustomPlot->addGraph();

    QPen pen;
    pen.setWidth(5);
    pen.setColor(_color);

    curGraph->setPen(pen);
    curGraph->setLineStyle(QCPGraph::lsNone);
    curGraph->setScatterStyle(QCPScatterStyle(QCPScatterStyle::ssCircle, 2));

    QVector<double> latVector(dataSpiral.size());
    QVector<double> lonVector(dataSpiral.size());

    for (int i = 0; i < dataSpiral.size(); ++i) {

        latVector[i] = dataSpiral[i].key;
        lonVector[i] = dataSpiral[i].value;
    }

    curGraph->setData(latVector, lonVector);

    //customPlot->rescaleAxes();
    //customPlot->replot();
}

void ChartForm::NewLine(int id, QColor _color, int _width)
{
    QCPCurve * cline_;

    cline_ = new QCPCurve(ui->qcustomPlot->xAxis, ui->qcustomPlot->yAxis);

    QPen pen;
    pen.setWidth(_width);
    pen.setColor(_color);

    cline_->setPen(pen);

    lines.insert({id, cline_});
}

void ChartForm::UpdateLine(int id, double x, double y)
{
    lines[id]->data()->add(QCPCurveData(x,x,y));

    ui->qcustomPlot->rescaleAxes();
    ui->qcustomPlot->replot();
}
